<?php

namespace Teknisa\MAN\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Utilities;

class RelObsParticularidadesVendaService {
	
	protected $entityManager;

	public function __construct(\Doctrine\ORM\EntityManager $entityManager)  {
		$this->entityManager = $entityManager;
	}
	
	public function getObservacoes($conditions) {

		$params = array(
			":NRORG"			=> $conditions['NRORG'],
			":CDFILIAL" 		=> array_key_exists('CDFILIAL', $conditions) ? implode('_', $conditions['CDFILIAL']) : NULL,
			":DTINI"			=> $conditions['DTENTRVENDA'][0],
			":DTFIM"			=> $conditions['DTENTRVENDA'][1]
		);

		return $this->entityManager->getConnection()->fetchAll(self::GET_OBSERVACOES_PARTICULARIDAS_VENDA, $params);
	}
	    
	const GET_OBSERVACOES_PARTICULARIDAS_VENDA = "
		SELECT F.CDFILIAL,
		  F.NMFILIAL,
		  (F.CDFILIAL ||' - '|| F.NMFILIAL) AS LABELFILIAL,
		  L.CDLOJA,
		  L.NMLOJA,
		  V.CDCAIXA,
		  NVL(V.NRNOTAFISCALCE, V.NRCUPOMFIS) AS CUPOM,
		  V.DTENTRVENDA,
		  P.CDPRODUTO,
		  P.CDARVPROD,
		  P.NMPRODUTO,
		  (P.CDARVPROD ||' - '|| P.NMPRODUTO) AS PRODUTO,
		  V.CDGRPOCORDESC,
		  G.DSGRPOCOR,
		  V.DSOBSFINVEN,
		  V.CDSUPERVISOR,
		  P1.NMOPERADOR AS NMSUPERVISOR,
		  V.CDOPERADOR,
		  P2.NMOPERADOR,
		  V.CDCONSUMIDOR,
		  O.NMCONSUMIDOR,
		  SUM(TRUNC(I.QTPRODVEND * (I.VRUNITVEND + NVL(I.VRUNITVENDCL,0)),2) + NVL(I.VRACRITVEND,0) - NVL(I.VRDESITVEND,0)) AS VRVENDA,
		  SUM(NVL(I.VRDESITVEND,0))                                                                                         AS VRDESC,
		  'CUPOM'                                                                                                           AS TIPODESC
		FROM FILIAL F,
		  LOJA L,
		  VENDA V,
		  ITEMVENDA I,
		  PRODUTO P,
		  GRUPOCOR G,
		  CONSUMIDOR O,
		  OPERADOR P1,
		  OPERADOR P2
		WHERE ((INSTR(:CDFILIAL, F.CDFILIAL ) <> 0))
		AND (L.CDFILIAL = F.CDFILIAL )
		AND (V.DTENTRVENDA BETWEEN :DTINI AND :DTFIM)
		AND (V.CDFILIAL      = L.CDFILIAL )
		AND (V.CDLOJA        = L.CDLOJA )
		AND (I.CDFILIAL      = V.CDFILIAL )
		AND (I.CDCAIXA       = V.CDCAIXA )
		AND (I.NRSEQVENDA    = V.NRSEQVENDA )
		AND (I.CDPRODUTO     = P.CDPRODUTO )
		AND (V.CDGRPOCORDESC = G.CDGRPOCOR (+))
		AND (V.CDCLIENTE     = O.CDCLIENTE (+))
		AND (V.CDCONSUMIDOR  = O.CDCONSUMIDOR(+))
		AND (V.CDSUPERVISOR  = P1.CDOPERADOR (+))
		AND (V.CDOPERADOR    = P2.CDOPERADOR (+))
		AND (V.DSOBSFINVEN  IS NOT NULL )
		GROUP BY F.CDFILIAL,
		  F.NMFILIAL,
		  L.CDLOJA,
		  L.NMLOJA,
		  V.CDCAIXA,
		  V.NRCUPOMFIS,
		  V.NRNOTAFISCALCE,
		  V.DTENTRVENDA,
		  P.CDPRODUTO,
		  P.CDARVPROD,
		  P.NMPRODUTO,
		  V.CDGRPOCORDESC,
		  G.DSGRPOCOR,
		  V.DSOBSFINVEN,
		  V.CDSUPERVISOR,
		  P1.NMOPERADOR,
		  V.CDOPERADOR,
		  P2.NMOPERADOR,
		  V.CDCONSUMIDOR,
		  O.NMCONSUMIDOR
		ORDER BY 1,2,3,4,5,6,7,8
	";	    
}
